@@ -1,5 +1,6 @@
 from dataclasses import dataclass
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Union
+from hashlib import sha256, sha3_256, blake2b
 
 from pycardano import Datum, PlutusData
 
@@ -7,6 +8,12 @@ from pycardano import Datum, PlutusData
 TxId = bytes
 
 
+@dataclass()
+class Nothing(PlutusData):
+    CONSTR_ID = 0
+    pass
+
+
 @dataclass()
 class TxOutRef(PlutusData):
     id: TxId
@@ -58,10 +65,16 @@ class StakingPtr(PlutusData):
 StakingCredential = Union[StakingHash, StakingPtr]
 
 
+@dataclass()
+class SomeStakingCredential(PlutusData):
+    CONSTR_ID = 1
+    staking_credential: StakingCredential
+
+
 @dataclass()
 class Address(PlutusData):
     credential: Credential
-    staking_credential: Optional[StakingCredential]
+    staking_credential: Union[Nothing, SomeStakingCredential]
 
 
 CurrencySymbol = bytes
@@ -73,11 +86,17 @@ Value = Dict[CurrencySymbol, Dict[TokenName, int]]
 DatumHash = bytes
 
 
+@dataclass()
+class SomeDatumHash(PlutusData):
+    CONSTR_ID = 1
+    datum_hash: DatumHash
+
+
 @dataclass()
 class TxOut(PlutusData):
     address: Address
     value: Value
-    datum_hash: Optional[DatumHash]
+    datum_hash: Union[Nothing, SomeDatumHash]
 
 
 @dataclass()
